@@ -239,6 +239,12 @@ class LBFGSB:
     def minimize(self):
         np = self.np
         eps = 1E-10
+        # check for feasibility
+        if np.any(self.lb > self.ub):
+            return OptimizeResult(x=self.x, fun=None, jac=None,
+                                  nit=0, nfev=0,
+                                  status=1, success=False,
+                                  message="Infeasible")
         x = self.force_bounds(self.x)
         if self.param['grad_test']:
             self.grad_test(x)
@@ -251,7 +257,9 @@ class LBFGSB:
 
         # check for early stopping
         if pg <= self.param['eps_pg']:
-            return x
+            return OptimizeResult(x=x, fun=f, jac=g,
+                                  nit=0, nfev=fun_eval, status=0, success=True,
+                                  message="Solved")
 
         # initial direction
         d = -g * self.working
@@ -328,6 +336,8 @@ class LBFGSB:
                 else:
                     # really cannot do any progress due to numerical errors
                     warnings.warn(f"Line search failed.", RuntimeWarning)
+                    status = 3
+                    message = "Line search failed"
                     break
 
             x = self.force_bounds(x)
@@ -339,9 +349,13 @@ class LBFGSB:
 
             # check for convergence
             if k >= self.param['max_iter']:
+                status = 2
+                message = "Maximum iterations reached"
                 break
 
             if pg <= self.param['eps_pg']:
+                status = 0
+                message = "Solved"
                 break
 
             s = x - x_old
@@ -361,7 +375,9 @@ class LBFGSB:
             x_old = x
             g_old = g
         return OptimizeResult(x=x, fun=f, jac=g,
-                              nit=k, nfev=fun_eval)
+                              nit=k, nfev=fun_eval,
+                              status=status, success=(status==0),
+                              message=message)
 
 
 
@@ -435,6 +451,7 @@ class Augmented_Lagrangian:
         n_inner = 0
         jac = 0
         constraint_error_old = np.inf
+        rho_increases = 0
         while True:
             k += 1
             if self.param['verbose'] >= 5:
@@ -446,6 +463,7 @@ class Augmented_Lagrangian:
             self.NLP.y = self.y
             solver = LBFGSB(self.NLP.aug_Lag_fg, self.x, np, self.lb, self.ub, self.param_LBFGSB)
             res = solver.minimize()
+
             self.x = res.x
             fun_eval += res.nfev
             n_inner += res.nit
@@ -463,20 +481,40 @@ class Augmented_Lagrangian:
 
             constraint_error_norm = np.linalg.norm(constraint_error, np.inf)
             if constraint_error_norm < self.param['constraint_tol']:
+                status = 0
+                message = "Solved"
+                break
+
+            if res.status==1: # augmented Lagrangian could not be solved
+                status = 1
+                message = "Infeasible"
                 break
 
             if k >= self.param['max_iter_outer']:
+                status = 2
+                message = "Maximum outer iterations reached"
                 break
 
             self.y = rho * aug_constraint_error
             if constraint_error_norm > constraint_error_old * 0.5:
                 rho *= 2
+                rho_increases += 1
+            else:
+                rho_increases = 0
             constraint_error_old = constraint_error_norm
+
+            if rho_increases > 20:
+                status = 1
+                message = "Infeasible"
+                break # problem seems infeasible
+
         f, g = self.NLP.fg(self.x)
         return OptimizeResult(x=self.x, y=self.y, fun=f, jac=jac,
                               nit=k, nfev=fun_eval, nInner=n_inner,
                               maxcv=constraint_error_norm,
-                              slack=0)
+                              slack=0,
+                              status=status, success=(status==0),
+                              message=message)
 
 
 
